@@ -115,7 +115,7 @@ void WidgetExplorerPrivate::initFilters()
                               KCategorizedItemsViewModels::Filter(QStringLiteral("running"), true),
                               QIcon::fromTheme(QStringLiteral("dialog-ok")));
 
-        filterModel.addFilter(i18n("Uninstallable"),
+        filterModel.addFilter(i18nc("@item:inmenu used in the widget filter. Filter widgets that can be un-installed from the system, which are usually installed by the user to a local place.", "Uninstallable"),
                               KCategorizedItemsViewModels::Filter(QStringLiteral("local"), true),
                               QIcon::fromTheme(QStringLiteral("edit-delete")));
 
@@ -132,7 +132,7 @@ void WidgetExplorerPrivate::initFilters()
         if (!plugin.isValid()) {
             continue;
         }
-        if (plugin.rawData().value("NoDisplay").toBool() || plugin.category() == QLatin1String("Containments") || plugin.category().isEmpty()) {
+        if (plugin.rawData().value(QStringLiteral("NoDisplay")).toBool() || plugin.category() == QLatin1String("Containments") || plugin.category().isEmpty()) {
             // we don't want to show the hidden category
             continue;
         }
@@ -452,10 +452,12 @@ void WidgetExplorer::immutabilityChanged(Plasma::Types::ImmutabilityType type)
 
 void WidgetExplorer::downloadWidgets()
 {
-    if (!d->newStuffDialog) {
-        d->newStuffDialog = new KNS3::QtQuickDialogWrapper(QLatin1String("plasmoids.knsrc"));
+    if (WidgetExplorerPrivate::newStuffDialog.isNull()) {
+        WidgetExplorerPrivate::newStuffDialog = new KNS3::QtQuickDialogWrapper(QStringLiteral("plasmoids.knsrc"));
+        connect(WidgetExplorerPrivate::newStuffDialog, &KNS3::QtQuickDialogWrapper::closed, WidgetExplorerPrivate::newStuffDialog, &QObject::deleteLater);
+
+        WidgetExplorerPrivate::newStuffDialog->open();
     }
-    d->newStuffDialog->open();
 
     Q_EMIT shouldClose();
 }
