@@ -18,13 +18,8 @@
     License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <KLocalizedString>
-
 #include "fingerprintmodel.h"
 
-#include "fprint_device_interface.h"
-#include "fprint_manager_interface.h"
-
 FingerprintModel::FingerprintModel(QObject* parent)
     : QObject(parent)
     , m_managerDbusInterface(new NetReactivatedFprintManagerInterface(QStringLiteral("net.reactivated.Fprint"), QStringLiteral("/net/reactivated/Fprint/Manager"), QDBusConnection::systemBus(), this))
