@@ -40,7 +40,6 @@ View::View(QWindow *)
     , m_offset(.5)
     , m_floating(false)
 {
-    setClearBeforeRendering(true);
     setColor(QColor(Qt::transparent));
     setFlags(Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint);
 
@@ -59,6 +58,8 @@ View::View(QWindow *)
         Q_UNUSED(names);
         if (group.name() == QLatin1String("General")) {
             loadConfig();
+        } else if (group.name() == QLatin1String("Plugins")) {
+            Q_EMIT helpEnabledChanged();
         }
     });
 
@@ -214,9 +215,17 @@ void View::positionOnScreen()
 
     QScreen *shownOnScreen = QGuiApplication::primaryScreen();
 
+    auto message = QDBusMessage::createMethodCall("org.kde.KWin", "/KWin", "org.kde.KWin", "activeOutputName");
+    QDBusReply<QString> reply = QDBusConnection::sessionBus().call(message);
+
     const auto screens = QGuiApplication::screens();
     for (QScreen *screen : screens) {
-        if (screen->geometry().contains(QCursor::pos(screen))) {
+        if (reply.isValid()) {
+            if (screen->name() == reply.value()) {
+                shownOnScreen = screen;
+                break;
+            }
+        } else if (screen->geometry().contains(QCursor::pos(screen))) {
             shownOnScreen = screen;
             break;
         }
@@ -225,7 +234,7 @@ void View::positionOnScreen()
     // in wayland, QScreen::availableGeometry() returns QScreen::geometry()
     // we could get a better value from plasmashell
     // BUG: 386114
-    auto message = QDBusMessage::createMethodCall("org.kde.plasmashell", "/StrutManager", "org.kde.PlasmaShell.StrutManager", "availableScreenRect");
+    message = QDBusMessage::createMethodCall("org.kde.plasmashell", "/StrutManager", "org.kde.PlasmaShell.StrutManager", "availableScreenRect");
     message.setArguments({shownOnScreen->name()});
     QDBusPendingCall call = QDBusConnection::sessionBus().asyncCall(message);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
@@ -256,14 +265,16 @@ void View::positionOnScreen()
         y = qBound(r.top(), y, r.bottom() - height());
 
         setPosition(x, y);
-        setLocation(m_floating ? Plasma::Types::Floating : Plasma::Types::TopEdge);
         PlasmaQuick::Dialog::setVisible(true);
 
         if (m_floating) {
             KWindowSystem::setOnDesktop(winId(), KWindowSystem::currentDesktop());
             KWindowSystem::setType(winId(), NET::Normal);
+            // Turn the sliding effect off
+            setLocation(Plasma::Types::Floating);
         } else {
             KWindowSystem::setOnAllDesktops(winId(), true);
+            setLocation(Plasma::Types::TopEdge);
         }
 
         KWindowSystem::forceActiveWindow(winId());
@@ -326,25 +337,10 @@ void View::switchUser()
 
 void View::displayConfiguration()
 {
-    const QString systemSettings = QStringLiteral("systemsettings");
-    const QStringList kcmToOpen = QStringList(QStringLiteral("kcm_plasmasearch"));
-    KIO::CommandLauncherJob *job = nullptr;
-
-    if (KService::serviceByDesktopName(systemSettings)) {
-        job = new KIO::CommandLauncherJob(QStringLiteral("systemsettings5"), kcmToOpen);
-        job->setDesktopName(systemSettings);
-    } else {
-        job = new KIO::CommandLauncherJob(QStringLiteral("kcmshell5"), kcmToOpen);
-    }
-
+    auto job = new KIO::CommandLauncherJob(QStringLiteral("kcmshell5"), {QStringLiteral("plasma/kcms/desktop/kcm_krunnersettings")});
     job->start();
 }
 
-bool View::canConfigure() const
-{
-    return KAuthorized::authorizeControlModule(QStringLiteral("kcm_plasmasearch.desktop"));
-}
-
 void View::setVisible(bool visible)
 {
     m_requestedVisible = visible;
