@@ -45,7 +45,7 @@ SessionBackend *SessionBackend::self()
 
 SessionBackend::SessionBackend()
 {
-    m_kserverConfig = KConfigWatcher::create(KSharedConfig::openConfig("ksmserverrc"));
+    m_kserverConfig = KConfigWatcher::create(KSharedConfig::openConfig(QStringLiteral("ksmserverrc")));
 }
 
 bool SessionBackend::confirmLogout() const
@@ -216,7 +216,7 @@ ConsoleKitSessionBackend::ConsoleKitSessionBackend()
     m_canSuspend = m_upower->canSuspend();
     m_canHibernate = m_upower->canHibernate();
 
-    connect(m_upower, &OrgFreedesktopUPowerInterface::AboutToSleep, this, &SessionBackend::aboutToSuspend);
+    connect(m_upower, &OrgFreedesktopUPowerInterface::NotifySleep, this, &SessionBackend::aboutToSuspend);
     connect(m_upower, &OrgFreedesktopUPowerInterface::Resuming, this, &SessionBackend::resumingFromSuspend);
 
     m_state = SessionManagement::State::Ready;
