@@ -18,8 +18,11 @@
 #include <KShell>
 
 #include <algorithm>
+#include <chrono>
 #include <functional>
 
+using namespace std::chrono_literals;
+
 static const int s_notificationsLimit = 1000;
 
 using namespace NotificationManager;
@@ -29,7 +32,7 @@ AbstractNotificationsModel::Private::Private(AbstractNotificationsModel *q)
     , lastRead(QDateTime::currentDateTimeUtc())
 {
     pendingRemovalTimer.setSingleShot(true);
-    pendingRemovalTimer.setInterval(50);
+    pendingRemovalTimer.setInterval(50ms);
     connect(&pendingRemovalTimer, &QTimer::timeout, q, [this, q] {
         QVector<int> rowsToBeRemoved;
         rowsToBeRemoved.reserve(pendingRemovals.count());
@@ -67,10 +70,10 @@ void AbstractNotificationsModel::Private::onNotificationAdded(const Notification
         q->endRemoveRows();
     }
 
-    setupNotificationTimeout(notification);
-
     q->beginInsertRows(QModelIndex(), notifications.count(), notifications.count());
     notifications.append(std::move(notification));
+    // Timeout must be set after the item appends to the vector
+    setupNotificationTimeout(notification);
     q->endInsertRows();
 }
 
@@ -159,6 +162,12 @@ void AbstractNotificationsModel::Private::setupNotificationTimeout(const Notific
         return;
     }
 
+    // Don't show the notification popup after switching DND mode off.
+    if (inhibited) {
+        q->expire(notification.id());
+        return;
+    }
+
     QTimer *timer = notificationTimeouts.value(notification.id());
     if (!timer) {
         timer = new QTimer();
@@ -426,6 +435,11 @@ void AbstractNotificationsModel::stopTimeout(uint notificationId)
     delete d->notificationTimeouts.take(notificationId);
 }
 
+void AbstractNotificationsModel::setInhibited(bool inhibited)
+{
+    d->inhibited = inhibited;
+}
+
 void AbstractNotificationsModel::clear(Notifications::ClearFlags flags)
 {
     if (d->notifications.isEmpty()) {
