@@ -838,13 +838,16 @@ void PanelView::resizeEvent(QResizeEvent *ev)
 {
     updateEnabledBorders();
     // don't setGeometry() to make really sure we aren't doing a resize loop
-    const QPoint pos = geometryByDistance(m_distance).topLeft();
-    setPosition(pos);
-    if (m_shellSurface) {
-        m_shellSurface->setPosition(pos);
+    if (m_screenToFollow) {
+        const QPoint pos = geometryByDistance(m_distance).topLeft();
+        setPosition(pos);
+        if (m_shellSurface) {
+            m_shellSurface->setPosition(pos);
+        }
+
+        m_strutsTimer.start(STRUTSTIMERDELAY);
+        Q_EMIT m_corona->availableScreenRegionChanged();
     }
-    m_strutsTimer.start(STRUTSTIMERDELAY);
-    Q_EMIT m_corona->availableScreenRegionChanged();
 
     PlasmaQuick::ContainmentView::resizeEvent(ev);
 }
@@ -854,9 +857,6 @@ void PanelView::moveEvent(QMoveEvent *ev)
     updateEnabledBorders();
     m_strutsTimer.start(STRUTSTIMERDELAY);
     PlasmaQuick::ContainmentView::moveEvent(ev);
-    if (!m_screenToFollow->geometry().contains(geometry())) {
-        positionPanel();
-    }
 }
 
 void PanelView::keyPressEvent(QKeyEvent *event)
@@ -935,10 +935,18 @@ void PanelView::setScreenToFollow(QScreen *screen)
         // disconnect from old screen
         disconnect(m_screenToFollow, &QScreen::virtualGeometryChanged, this, &PanelView::updateStruts);
         disconnect(m_screenToFollow, &QScreen::geometryChanged, this, &PanelView::restore);
+        // Workaround for https://codereview.qt-project.org/c/qt/qtbase/+/413380
+        if (KWindowSystem::isPlatformX11()) {
+            disconnect(m_screenToFollow, &QScreen::logicalDotsPerInchChanged, this, &PanelView::restore);
+        }
     }
 
     connect(screen, &QScreen::virtualGeometryChanged, this, &PanelView::updateStruts, Qt::UniqueConnection);
     connect(screen, &QScreen::geometryChanged, this, &PanelView::restore, Qt::UniqueConnection);
+    // Workaround for https://codereview.qt-project.org/c/qt/qtbase/+/413380
+    if (KWindowSystem::isPlatformX11()) {
+        connect(screen, &QScreen::logicalDotsPerInchChanged, this, &PanelView::restore, Qt::UniqueConnection);
+    }
 
     /*connect(screen, &QObject::destroyed, this, [this]() {
         if (PanelView::screen()) {
