@@ -19,7 +19,11 @@
 #include <config-plasma.h>
 #if HAVE_X11
 #include <QTimer> //Used only in x11 case
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
+#endif
 #include <xcb/randr.h>
 #include <xcb/xcb.h>
 #include <xcb/xcb_event.h>
@@ -108,7 +112,11 @@ void PrimaryOutputWatcher::setupRegistry()
     m_registry->setup();
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 bool PrimaryOutputWatcher::nativeEventFilter(const QByteArray &eventType, void *message, long int *result)
+#else
+bool PrimaryOutputWatcher::nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result)
+#endif
 {
     Q_UNUSED(result);
 #if HAVE_X11
